summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/label.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kalarm/lib/label.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/lib/label.h')
-rw-r--r--kalarm/lib/label.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kalarm/lib/label.h b/kalarm/lib/label.h
index bd0e3903..ba418aee 100644
--- a/kalarm/lib/label.h
+++ b/kalarm/lib/label.h
@@ -45,29 +45,29 @@ class Label : public TQLabel
friend class LabelFocusWidget;
public:
/** Constructs an empty label.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
*/
- explicit Label(TQWidget* tqparent, const char* name = 0, WFlags f = 0);
+ explicit Label(TQWidget* parent, const char* name = 0, WFlags f = 0);
/** Constructs a label that displays @p text.
* @param text Text string to display.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
*/
- Label(const TQString& text, TQWidget* tqparent, const char* name = 0, WFlags f = 0);
+ Label(const TQString& text, TQWidget* parent, const char* name = 0, WFlags f = 0);
/** Constructs a label, with a buddy widget, that displays @p text.
* @param buddy Buddy widget which receives the keyboard focus when the
* label's accelerator key is pressed. If @p buddy is a radio
* button, @p buddy is in addition selected when the
* accelerator key is pressed.
* @param text Text string to display.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
*/
- Label(TQWidget* buddy, const TQString& text, TQWidget* tqparent, const char* name = 0, WFlags f = 0);
+ Label(TQWidget* buddy, const TQString& text, TQWidget* parent, const char* name = 0, WFlags f = 0);
/** Sets the label's buddy widget which receives the keyboard focus when the
* label's accelerator key is pressed. If @p buddy is a radio button,
* @p buddy is in addition selected when the accelerator key is pressed.
@@ -90,7 +90,7 @@ class LabelFocusWidget : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- LabelFocusWidget(TQWidget* tqparent, const char* name = 0);
+ LabelFocusWidget(TQWidget* parent, const char* name = 0);
protected:
virtual void focusInEvent(TQFocusEvent*);
};
@@ -45,29 +45,29 @@ class Label : public TQLabel
public:
/** Constructs an empty label.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
@@ -45,29 +45,29 @@ class Label : public TQLabel
/** Constructs a label that displays @p text.
* @param text Text string to display.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.
@@ -45,29 +45,29 @@ class Label : public TQLabel
* accelerator key is pressed.
* @param text Text string to display.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
* @param f Flags. See TQWidget constructor for details.